Legend can control alignment of title and handles
-------------------------------------------------

`.Legend` now supports control the alignment of title and handles via the
keyword argument ``alignment``. You can also use `.Legend.set_alignment`
to control the alignment on existing Legends.
